PyMC Extras
===================================================
|Tests|
|Coverage|
|Black|


.. |Tests| image:: https://github.com/pymc-devs/pymc-extras/actions/workflows/test.yml/badge.svg
    :target: https://github.com/pymc-devs/pymc-extras

.. |Coverage| image:: https://codecov.io/gh/pymc-devs/pymc-extras/branch/main/graph/badge.svg?token=ZqH0KCLKAE
    :target: https://codecov.io/gh/pymc-devs/pymc-extras



Where we grow the next batch of cool PyMC features

Installation
============

To install the latest release on `PyPI <https://pypi.org/project/pymc-extras/>`_, you can use a package manager like pip:

.. code-block:: bash

   pip install pymc-extras

For the development version, you can install directly from GitHub:

.. code-block:: bash

  pip install git+https://github.com/pymc-devs/pymc-extras.git

Contributing
============
We welcome contributions from interested individuals or groups! For information about contributing to PyMC Extras check out our instructions, policies, and guidelines `here <https://github.com/pymc-devs/pymc-extras/blob/main/CONTRIBUTING.md>`_.

Contributors
============
See the `GitHub contributor page <https://github.com/pymc-devs/pymc-extras/graphs/contributors>`_.

.. toctree::
   :hidden:

   api_reference
